"""
VenusAI: A Python package for building powerful AI agents.
"""

__author__ = "Mert Sırakaya"
__maintainer__ = "https://github.com/fswair"
__email__ = "contact@tomris.dev"
__version__ = "0.0.1"
__license__ = "MIT"

import this